@@ -1003,10 +1003,14 @@ end
 -- @tparam number|nil forced_num_rows Forced number of rows (`nil` for automatic).
 -- @tparam widget ... Widgets that should be added to the layout.
 -- @function wibox.layout.grid.horizontal
-function grid.horizontal(forced_num_rows, ...)
+function grid.horizontal(forced_num_rows, widget, ...)
     local ret = new("horizontal")
     ret:set_forced_num_rows(forced_num_rows)
-    ret:add(...)
+
+    if widget then
+        ret:add(widget, ...)
+    end
+
     return ret
 end
 
@@ -1017,10 +1021,14 @@ end
 -- @tparam number|nil forced_num_cols Forced number of columns (`nil` for automatic).
 -- @tparam widget ... Widgets that should be added to the layout.
 -- @function wibox.layout.grid.vertical
-function grid.vertical(forced_num_cols, ...)
+function grid.vertical(forced_num_cols, widget, ...)
     local ret = new("vertical")
     ret:set_forced_num_cols(forced_num_cols)
-    ret:add(...)
+
+    if widget then
+        ret:add(widget, ...)
+    end
+
     return ret
 end
 
@@ -1029,16 +1037,14 @@ function grid.mt:__call(...)
     return new(...)
 end
 
---Imported documentation
-
-
---- Get a widex index.
+--
+--- Get a widget index.
 -- @param widget The widget to look for
 -- @param[opt] recursive Also check sub-widgets
--- @param[opt] ... Aditional widgets to add at the end of the \"path\"
+-- @param[opt] ... Additional widgets to add at the end of the path
 -- @return The index
 -- @return The parent layout
--- @return The path between \"self\" and \"widget\"
+-- @return The path between self and widget
 -- @function index
 
 --- Get all direct and indirect children widgets.
@@ -1198,39 +1204,37 @@ end
 -- in its local coordinate system.
 -- @see mouse
 
-
---Imported documentation
-
-
---- Disconnect to a signal.
--- @tparam string name The name of the signal
--- @tparam function func The callback that should be disconnected
+--
+--- Disconnect from a signal.
+-- @tparam string name The name of the signal.
+-- @tparam function func The callback that should be disconnected.
 -- @function disconnect_signal
 
 --- Emit a signal.
 --
--- @tparam string name The name of the signal
+-- @tparam string name The name of the signal.
 -- @param ... Extra arguments for the callback functions. Each connected
---   function receives the object as first argument and then any extra arguments
---   that are given to emit_signal()
+--   function receives the object as first argument and then any extra
+--   arguments that are given to emit_signal().
 -- @function emit_signal
 
 --- Connect to a signal.
--- @tparam string name The name of the signal
--- @tparam function func The callback to call when the signal is emitted
+-- @tparam string name The name of the signal.
+-- @tparam function func The callback to call when the signal is emitted.
 -- @function connect_signal
 
---- Connect to a signal weakly. This allows the callback function to be garbage
--- collected and automatically disconnects the signal when that happens.
+--- Connect to a signal weakly.
+--
+-- This allows the callback function to be garbage collected and
+-- automatically disconnects the signal when that happens.
 --
 -- **Warning:**
 -- Only use this function if you really, really, really know what you
 -- are doing.
--- @tparam string name The name of the signal
--- @tparam function func The callback to call when the signal is emitted
+-- @tparam string name The name of the signal.
+-- @tparam function func The callback to call when the signal is emitted.
 -- @function weak_connect_signal
 
-
 return setmetatable(grid, grid.mt)
 
 -- vim: filetype=lua:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:textwidth=80
